@@ -9,7 +9,7 @@ BEGIN { @JSON::ISA = 'Exporter' }
 @JSON::EXPORT = qw(from_json to_json jsonToObj objToJson encode_json decode_json);
 
 BEGIN {
-    $JSON::VERSION = '3.99_01';
+    $JSON::VERSION = '4.01';
     $JSON::DEBUG   = 0 unless (defined $JSON::DEBUG);
     $JSON::DEBUG   = $ENV{ PERL_JSON_DEBUG } if exists $ENV{ PERL_JSON_DEBUG };
 }
@@ -196,6 +196,11 @@ sub true  { $JSON::true  }
 
 sub false { $JSON::false }
 
+sub boolean {
+    # might be called as method or as function, so pop() to get the last arg instead of shift() to get the first
+    pop() ? $JSON::true : $JSON::false
+}
+
 sub null  { undef; }
 
 
@@ -473,7 +478,7 @@ JSON - JSON (JavaScript Object Notation) encoder/decoder
 
 =head1 VERSION
 
-    3.99_01
+    4.01
 
 =head1 DESCRIPTION
 
@@ -1254,6 +1259,13 @@ Returns a reference to a hash that holds all the common flag settings.
 
 You can use this to get/set a value of a particular flag.
 
+=head2 boolean
+
+    $boolean_object = JSON->boolean($scalar)
+
+Returns $JSON::true if $scalar contains a true value, $JSON::false otherwise.
+You can use this as a full-qualified function (C<JSON::boolean($scalar)>).
+
 =head1 INCREMENTAL PARSING
 
 This section is also taken from JSON::XS.
@@ -1787,13 +1799,9 @@ a particular boolean class or not.
 Please report bugs on backend selection and additional features
 this module provides to RT or GitHub issues for this module:
 
-=over 4
+L<https://rt.cpan.org/Public/Dist/Display.html?Queue=JSON>
 
-=item https://rt.cpan.org/Public/Dist/Display.html?Queue=JSON
-
-=item https://github.com/makamaka/JSON/issues
-
-=back
+L<https://github.com/makamaka/JSON/issues>
 
 As for bugs on a specific behavior, please report to the author
 of the backend module you are using.
